==> open-cluster-management-apps-model-5.12.4-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/AnsibleJobsStatus.java <==

package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "lastposthookjob",
    "lastprehookjob",
    "posthookjobshistory",
    "prehookjobshistory"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class AnsibleJobsStatus implements KubernetesResource
{

    @JsonProperty("lastposthookjob")
    private String lastposthookjob;
    @JsonProperty("lastprehookjob")
    private String lastprehookjob;
    @JsonProperty("posthookjobshistory")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<String> posthookjobshistory = new ArrayList<String>();
    @JsonProperty("prehookjobshistory")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<String> prehookjobshistory = new ArrayList<String>();
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public AnsibleJobsStatus() {
    }

    /**
     * 
     * @param lastposthookjob
     * @param lastprehookjob
     * @param prehookjobshistory
     * @param posthookjobshistory
     */
    public AnsibleJobsStatus(String lastposthookjob, String lastprehookjob, List<String> posthookjobshistory, List<String> prehookjobshistory) {
        super();
        this.lastposthookjob = lastposthookjob;
        this.lastprehookjob = lastprehookjob;
        this.posthookjobshistory = posthookjobshistory;
        this.prehookjobshistory = prehookjobshistory;
    }

    @JsonProperty("lastposthookjob")
    public String getLastposthookjob() {
        return lastposthookjob;
    }

    @JsonProperty("lastposthookjob")
    public void setLastposthookjob(String lastposthookjob) {
        this.lastposthookjob = lastposthookjob;
    }

    @JsonProperty("lastprehookjob")
    public String getLastprehookjob() {
        return lastprehookjob;
    }

    @JsonProperty("lastprehookjob")
    public void setLastprehookjob(String lastprehookjob) {
        this.lastprehookjob = lastprehookjob;
    }

    @JsonProperty("posthookjobshistory")
    public List<String> getPosthookjobshistory() {
        return posthookjobshistory;
    }

    @JsonProperty("posthookjobshistory")
    public void setPosthookjobshistory(List<String> posthookjobshistory) {
        this.posthookjobshistory = posthookjobshistory;
    }

    @JsonProperty("prehookjobshistory")
    public List<String> getPrehookjobshistory() {
        return prehookjobshistory;
    }

    @JsonProperty("prehookjobshistory")
    public void setPrehookjobshistory(List<String> prehookjobshistory) {
        this.prehookjobshistory = prehookjobshistory;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/AnsibleJobsStatus.java <==

package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "lastposthookjob",
    "lastprehookjob",
    "posthookjobshistory",
    "prehookjobshistory"
})
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, lazyCollectionInitEnabled = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(ObjectMeta.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(PodTemplateSpec.class),
    @BuildableReference(ResourceRequirements.class),
    @BuildableReference(IntOrString.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LocalObjectReference.class),
    @BuildableReference(PersistentVolumeClaim.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class AnsibleJobsStatus implements KubernetesResource
{

    @JsonProperty("lastposthookjob")
    private String lastposthookjob;
    @JsonProperty("lastprehookjob")
    private String lastprehookjob;
    @JsonProperty("posthookjobshistory")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<String> posthookjobshistory = new ArrayList<String>();
    @JsonProperty("prehookjobshistory")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<String> prehookjobshistory = new ArrayList<String>();
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public AnsibleJobsStatus() {
    }

    /**
     * 
     * @param lastposthookjob
     * @param lastprehookjob
     * @param prehookjobshistory
     * @param posthookjobshistory
     */
    public AnsibleJobsStatus(String lastposthookjob, String lastprehookjob, List<String> posthookjobshistory, List<String> prehookjobshistory) {
        super();
        this.lastposthookjob = lastposthookjob;
        this.lastprehookjob = lastprehookjob;
        this.posthookjobshistory = posthookjobshistory;
        this.prehookjobshistory = prehookjobshistory;
    }

    @JsonProperty("lastposthookjob")
    public String getLastposthookjob() {
        return lastposthookjob;
    }

    @JsonProperty("lastposthookjob")
    public void setLastposthookjob(String lastposthookjob) {
        this.lastposthookjob = lastposthookjob;
    }

    @JsonProperty("lastprehookjob")
    public String getLastprehookjob() {
        return lastprehookjob;
    }

    @JsonProperty("lastprehookjob")
    public void setLastprehookjob(String lastprehookjob) {
        this.lastprehookjob = lastprehookjob;
    }

    @JsonProperty("posthookjobshistory")
    public List<String> getPosthookjobshistory() {
        return posthookjobshistory;
    }

    @JsonProperty("posthookjobshistory")
    public void setPosthookjobshistory(List<String> posthookjobshistory) {
        this.posthookjobshistory = posthookjobshistory;
    }

    @JsonProperty("prehookjobshistory")
    public List<String> getPrehookjobshistory() {
        return prehookjobshistory;
    }

    @JsonProperty("prehookjobshistory")
    public void setPrehookjobshistory(List<String> prehookjobshistory) {
        this.prehookjobshistory = prehookjobshistory;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
